==> YNQ-1.5.0_Linux_S_CP.zip: YNQ-1.5.0_Linux_S_CP/NQ Library Reference/html/group__file.js <==
var group__file =
[
    [ "File attributes", "group__attributes.html", "group__attributes" ],
    [ "File access mode", "group__access.html", "group__access" ],
    [ "File share mode", "group__share.html", "group__share" ],
    [ "File locality", "group__locality.html", "group__locality" ],
    [ "File create action", "group__create.html", "group__create" ],
    [ "File open action", "group__open.html", "group__open" ],
    [ "File seek constants", "group__seek.html", "group__seek" ],
    [ "CCServerSideCopyCallback", "group__file.html#gacb15acb85f80767a02c78804dde2352c", null ],
    [ "ccCreateFileA", "group__file.html#gac99c068415f9a004f3186e1d7ebd20de", null ],
    [ "ccCreateFile", "group__file.html#ga368c3f1d60533cfacc094e2a389574c9", null ],
    [ "ccDeleteFileA", "group__file.html#ga12ae15ad7e4adb3f61b0eff1ae22b5b1", null ],
    [ "ccDeleteFile", "group__file.html#ga476260fe0f8cbb4946b83986cba2d750", null ],
    [ "ccMoveFileA", "group__file.html#ga5af11ec3dfbb8c8945820996dcbae6a3", null ],
    [ "ccMoveFile", "group__file.html#gad3c8829bea2d58873a5fc6b5ebc75208", null ],
    [ "ccReadFile", "group__file.html#gaa79aa20c627570c7f84d80cf34442719", null ],
    [ "ccReadFileAsync", "group__file.html#gaffefc4d82edc57559231a10b12080cc3", null ],
    [ "ccWriteFile", "group__file.html#ga64fa52ea63bf8c97de5b4f09318b29e1", null ],
    [ "ccWriteFileAsync", "group__file.html#gadcdaad3b34d267c3db02e36c4a0abc98", null ],
    [ "ccFlushFile", "group__file.html#gaca2b776c17739551f08a5392415d0353", null ],
    [ "ccCloseHandle", "group__file.html#ga4b49f4f5d869170edb3e9163ff235fa7", null ]
];

==> YNQ-1.6.0_Linux_S_CP.zip: YNQ-1.6.0_Linux_S_CP/NQ Library Reference/html/group__file.js <==
var group__file =
[
    [ "File Attributes", "group__attributes.html", "group__attributes" ],
    [ "File Access Mode", "group__access.html", "group__access" ],
    [ "File Share Mode", "group__share.html", "group__share" ],
    [ "File Locality", "group__locality.html", "group__locality" ],
    [ "File Create Action", "group__create.html", "group__create" ],
    [ "File Open Action", "group__open.html", "group__open" ],
    [ "File Seek Constants", "group__seek.html", "group__seek" ],
    [ "CCServerSideCopyCallback", "group__file.html#gacb15acb85f80767a02c78804dde2352c", null ],
    [ "ccCreateFileA", "group__file.html#gac99c068415f9a004f3186e1d7ebd20de", null ],
    [ "ccCreateFile", "group__file.html#ga368c3f1d60533cfacc094e2a389574c9", null ],
    [ "ccDeleteFileA", "group__file.html#ga12ae15ad7e4adb3f61b0eff1ae22b5b1", null ],
    [ "ccDeleteFile", "group__file.html#ga476260fe0f8cbb4946b83986cba2d750", null ],
    [ "ccMoveFileA", "group__file.html#ga5af11ec3dfbb8c8945820996dcbae6a3", null ],
    [ "ccMoveFile", "group__file.html#gad3c8829bea2d58873a5fc6b5ebc75208", null ],
    [ "ccReadFile", "group__file.html#gaa79aa20c627570c7f84d80cf34442719", null ],
    [ "ccReadFileAsync", "group__file.html#gaffefc4d82edc57559231a10b12080cc3", null ],
    [ "ccWriteFile", "group__file.html#ga64fa52ea63bf8c97de5b4f09318b29e1", null ],
    [ "ccWriteFileAsync", "group__file.html#gadcdaad3b34d267c3db02e36c4a0abc98", null ],
    [ "ccFlushFile", "group__file.html#gaca2b776c17739551f08a5392415d0353", null ],
    [ "ccCloseHandle", "group__file.html#ga4b49f4f5d869170edb3e9163ff235fa7", null ]
];
